@@ -14,7 +14,7 @@ import numpy as np
 import getpass
 import pprint
 from .. import haven_jupyter as hj
-from . import utils_toolkit as ho
+from . import toolkit_manager as ho
 
 
 
@@ -92,7 +92,7 @@ class JobManager:
                     in_parallel=True):
         exp_list = exp_list or self.exp_list
         summary_list = self.get_summary_list(get_logs=False, exp_list=exp_list)
-        summary_dict = hr.group_list(summary_list, key='job_state', return_count=True)
+        summary_dict = hu.group_list(summary_list, key='job_state', return_count=True)
 
         print("\nTotal Experiments:", len(exp_list))
         print("Experiment Status:", summary_dict)
@@ -123,11 +123,24 @@ class JobManager:
 
         elif option == 'reset':
             self.verbose = False
-            self.launch_exp_list(command=command, exp_list=exp_list, reset=1, in_parallel=in_parallel)
+            for e_list in chunk_list(exp_list, n=100):
+                self.launch_exp_list(command=command, exp_list=e_list, reset=1, in_parallel=in_parallel)
 
         elif option == 'run':
             self.verbose = False
-            self.launch_exp_list(command=command, exp_list=exp_list, reset=0, in_parallel=in_parallel)
+            tmp_list = [s_dict['exp_dict'] for s_dict in summary_list if s_dict['job_state'] not in ['RUNNING', 
+                                                                                      'QUEUED', 
+                                                                                      'SUCCEEDED', 
+                                                                                      'QUEUING']]
+
+            print('Selected %d/%d exps' % (len(tmp_list), len(exp_list)))
+            exp_list = tmp_list
+            if len(exp_list) == 0:
+                print('All experiments have ran.')
+                return
+
+            for e_list in chunk_list(exp_list, n=100):
+                self.launch_exp_list(command=command, exp_list=e_list, reset=0, in_parallel=in_parallel)
 
         elif option == 'kill':
             self.verbose = False
@@ -140,7 +153,7 @@ class JobManager:
 
     def print_job_status(self, exp_list):
         summary_list = self.get_summary_list(get_logs=False, exp_list=exp_list)
-        summary_dict = hr.group_list(summary_list, key='job_state', return_count=False)
+        summary_dict = hu.group_list(summary_list, key='job_state', return_count=False)
         
         for k in summary_dict.keys():
             n_jobs = len(summary_dict[k])
@@ -148,7 +161,7 @@ class JobManager:
                 print('\nExperiments %s: %d' % (k, n_jobs))
                 print(pd.DataFrame(summary_dict[k]).head())
 
-        summary_dict = hr.group_list(summary_list, key='job_state', return_count=True)
+        summary_dict = hu.group_list(summary_list, key='job_state', return_count=True)
         print(summary_dict)
 
     def launch_exp_list(self, command,  exp_list=None, savedir_base=None, reset=0, in_parallel=True):
@@ -493,4 +506,7 @@ def run_exp_list_jobs(exp_list,
                     account_id=account_id,
                     token=token)
 
-    jm.run()
\ No newline at end of file
+    jm.run()
+
+def chunk_list(my_list, n=100):
+    return [my_list[x:x+n] for x in range(0, len(my_list), n)]
\ No newline at end of file
